@@ -23,7 +23,7 @@ library(patchwork)
     overlay_position_FP = 12.1,
     label_title = "PPV",
     label_subtitle = "Screening test"
-  )    
+  )
 
 
 
@@ -34,17 +34,18 @@ library(patchwork)
     min_Prevalence = 1,
     max_Prevalence = 80,
     Specificity = 87.9,
+    Sensitivity = 90,
     overlay = "area",
     overlay_prevalence_1 = 1,
     overlay_prevalence_2 = 69,
     overlay_position_FN = 5,
     label_title = "NPV",
     label_subtitle = "Screening test"
-  )
+  ) 
 
 
 ## ----fig.height = 14, fig.width = 12------------------------------------------
 
-  (PPV_plot / NPV_plot) +  plot_layout(guides = 'collect')
+  (PPV_plot$p | NPV_plot$p +  ggplot2::labs(y = "")) +  plot_layout(guides = 'collect')
 
 
